@@ -10,20 +10,24 @@ Analizo::Metric::AverageCycloComplexity - Average Cyclomatic Complexity per Meth
 =head1 DESCRIPTION
 
 The metric calculation is based on the following article and calculates the
-complexity of the program.
+cyclomatic complexity of the program.
 
-Article: I<Monitoring of source code metrics in open source projects> by Paulo
-Roberto Miranda Meirelles.
+Article:
+I<McCabe, Thomas J. "A complexity measure." IEEE Transactions on software Engineering 4 (1976): 308-320>.
 
-See the adaptation of the paragraph about Average Cyclomatic Complexity per
-Method in the article:
+The Average Cyclomatic Complexity per Method is calculated counting the
+predicates (i.e., decision points, or conditional paths) on each method plus
+one, then a mean of all methods is returned as the final value of ACCM.
 
-... The cyclomatic complexity of a graph can be calculated using a formula of
-graph theory:
+The cyclomatic complexity of a program represented as a graph can be calculated
+using a formula of graph theory:
 
   v(G) = e - n + 2
 
-where C<e> is the number of edges and C<n> is the number of nodes of the graph.
+Where C<e> is the number of edges and C<n> is the number of nodes of the graph.
+
+Another good reference is:
+I<Woodward, Martin R., Michael A. Hennell, and David Hedley. "A measure of control flow complexity in program text." IEEE Transactions on Software Engineering 1 (1979): 45-50>.
 
 =cut
 
@@ -51,7 +55,7 @@ sub calculate {
 
   my $statisticalCalculator = Statistics::Descriptive::Full->new();
   for my $function (@functions) {
-    $statisticalCalculator->add_data($self->model->{conditional_paths}->{$function} || 0);
+    $statisticalCalculator->add_data($self->model->{conditional_paths}->{$function} + 1);
   }
 
   return $statisticalCalculator->mean();
